@@ -1,7 +1,7 @@
 from .sobjects import describe
 from .sobject_query import query_records
 from .sobject_create import create
-from .intelligent_sync import sync_sobject_intelligent, IntelligentSync, sync_with_debug
+from .intelligent_sync import sync_sobject_intelligent, IntelligentSync
 from .query_bapi20 import (
     create_batch_query,
     query_status,
