@@ -7,4 +7,8 @@ from .data_writer import (
     validate_dataframe_types,
     standardize_dataframe_types,
     write_dataframe_with_type_handling
+)
+from .table_creator import (
+    create_salesforce_table,
+    ensure_table_exists_for_dataframe
 )
\ No newline at end of file
